/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.social.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.CommonConstants;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.social.entity.TSocialLog;
import com.yifu.cloud.plus.v1.yifu.social.service.TSocialLogService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 社保变更记录表
 *
 * @author hgw
 * @date 2022-07-11 18:21:23
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tsociallog")
@Tag(name = "社保变更记录表管理")
public class TSocialLogController {

	private final TSocialLogService tSocialLogService;


	/**
	 * 简单分页查询
	 *
	 * @param page       分页对象
	 * @param tSocialLog 社保变更记录表
	 * @return
	 */
	@Operation(summary = "分页查询", description = "分页查询")
	@GetMapping("/page")
	public R<IPage<TSocialLog>> getTSocialLogPage(Page<TSocialLog> page, TSocialLog tSocialLog) {
		return new R<>(tSocialLogService.getTSocialLogPage(page, tSocialLog));
	}

	/**
	 * 不分页查询
	 *
	 * @param tSocialLog 社保变更记录表
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('social_tsociallog_get')" )
	public R<List<TSocialLog>> getTSocialLogNoPage(@RequestBody TSocialLog tSocialLog) {
		return R.ok(tSocialLogService.list(Wrappers.query(tSocialLog).orderByDesc(CommonConstants.CREATE_TIME)));
	}

	/**
	 * 通过id查询社保变更记录表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('social_tsociallog_get')")
	@GetMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('social_tsociallog_get')")
	public R<TSocialLog> getById(@PathVariable("id") String id) {
		return R.ok(tSocialLogService.getById(id));
	}

	/**
	 * 新增社保变更记录表
	 *
	 * @param tSocialLog 社保变更记录表
	 * @return R
	 */
	@Operation(summary = "新增社保变更记录表", description = "新增社保变更记录表：hasPermission('social_tsociallog_add')")
	@SysLog("新增社保变更记录表")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('social_tsociallog_add')")
	public R<Boolean> save(@RequestBody TSocialLog tSocialLog) {
		return R.ok(tSocialLogService.save(tSocialLog));
	}

	/**
	 * 修改社保变更记录表
	 *
	 * @param tSocialLog 社保变更记录表
	 * @return R
	 */
	@Operation(summary = "修改社保变更记录表", description = "修改社保变更记录表：hasPermission('social_tsociallog_edit')")
	@SysLog("修改社保变更记录表")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('social_tsociallog_edit')")
	public R<Boolean> updateById(@RequestBody TSocialLog tSocialLog) {
		return R.ok(tSocialLogService.updateById(tSocialLog));
	}

	/**
	 * 通过id删除社保变更记录表
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除社保变更记录表", description = "通过id删除社保变更记录表：hasPermission('social_tsociallog_del')")
	@SysLog("通过id删除社保变更记录表")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('social_tsociallog_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tSocialLogService.removeById(id));
	}

}
